@@ -1,16 +1,16 @@
-# Copyright (c) 2023, Oracle and/or its affiliates.
+# Copyright (c) 2023, 2024, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
 # published by the Free Software Foundation.
 #
-# This program is also distributed with certain software (including
+# This program is designed to work with certain software (including
 # but not limited to OpenSSL) that is licensed under separate terms,
 # as designated in a particular file or component or in included license
-# documentation.  The authors of MySQL hereby grant you an
+# documentation. The authors of MySQL hereby grant you an
 # additional permission to link the program and your derivative works
-# with the separately licensed software that they have included with
-# MySQL.
+# with the separately licensed software that they have either included with
+# the program or referenced in the documentation.
 #
 # Without limiting anything contained in the foregoing, this file,
 # which is part of MySQL Connector/Python, is also subject to the
@@ -38,7 +38,6 @@ __all__ = ["MySQLConnectionAbstract", "MySQLCursorAbstract", "ServerInfo"]
 import asyncio
 import os
 import re
-import warnings
 import weakref
 
 from abc import ABC, abstractmethod
@@ -70,13 +69,14 @@ from ..abstracts import (
     MYSQL_PY_TYPES,
     TLS_V1_3_SUPPORTED,
     TLS_VER_NO_SUPPORTED,
-    TLS_VERSION_DEPRECATED_ERROR,
     TLS_VERSION_ERROR,
+    TLS_VERSION_UNACCEPTABLE_ERROR,
 )
 from ..constants import (
     CONN_ATTRS_DN,
     DEFAULT_CONFIGURATION,
-    DEPRECATED_TLS_VERSIONS,
+    MYSQL_DEFAULT_CHARSET_ID_57,
+    MYSQL_DEFAULT_CHARSET_ID_80,
     OPENSSL_CS_NAMES,
     TLS_CIPHER_SUITES,
     TLS_VERSIONS,
@@ -90,6 +90,7 @@ from ..errors import (
     NotSupportedError,
     ProgrammingError,
 )
+from ..tls_ciphers import UNACCEPTABLE_TLS_CIPHERSUITES, UNACCEPTABLE_TLS_VERSIONS
 from ..types import (
     BinaryProtocolType,
     DescriptionType,
@@ -182,7 +183,6 @@ class MySQLConnectionAbstract(ABC):
         raw: bool = False,
         kerberos_auth_mode: Optional[str] = None,
         krb_service_principal: Optional[str] = None,
-        fido_callback: Optional[Union[str, Callable[[str], None]]] = None,
         webauthn_callback: Optional[Union[str, Callable[[str], None]]] = None,
         allow_local_infile: bool = DEFAULT_CONFIGURATION["allow_local_infile"],
         allow_local_infile_in_path: Optional[str] = DEFAULT_CONFIGURATION[
@@ -192,15 +192,25 @@ class MySQLConnectionAbstract(ABC):
         converter_str_fallback: bool = False,
         connection_timeout: int = DEFAULT_CONFIGURATION["connect_timeout"],
         unix_socket: Optional[str] = None,
+        use_unicode: Optional[bool] = True,
         ssl_ca: Optional[str] = None,
         ssl_cert: Optional[str] = None,
         ssl_key: Optional[str] = None,
         ssl_verify_cert: Optional[bool] = False,
         ssl_verify_identity: Optional[bool] = False,
         ssl_disabled: Optional[bool] = DEFAULT_CONFIGURATION["ssl_disabled"],
-        tls_versions: Optional[List[str]] = [],
+        tls_versions: Optional[List[str]] = None,
+        tls_ciphersuites: Optional[List[str]] = None,
         loop: Optional[asyncio.AbstractEventLoop] = None,
     ):
+        # private (shouldn't be manipulated directly internally)
+        self.__charset: Optional[Charset] = None
+        """It shouldn't be manipulated directly, even internally. If you need
+        to manipulate the charset object, use the property `_charset` (read & write)
+        instead. Similarly, `_charset` shouldn't be manipulated externally.
+        """
+
+        # protected (can be manipulated directly internally)
         self._user: str = user
         self._password: str = password
         self._host: str = host
@@ -220,9 +230,10 @@ class MySQLConnectionAbstract(ABC):
         self._init_command: Optional[str] = init_command
         self._protocol: MySQLProtocol = MySQLProtocol()
         self._socket: Optional[Union[MySQLTcpSocket, MySQLUnixSocket]] = None
-        self._charset: Optional[Charset] = None
         self._charset_name: Optional[str] = charset
+        """Charset name provided by the user at connection time."""
         self._charset_collation: Optional[str] = collation
+        """Collation provided by the user at connection time."""
         self._ssl_active: bool = False
         self._ssl_disabled: bool = ssl_disabled
         self._ssl_ca: Optional[str] = ssl_ca
@@ -231,7 +242,7 @@ class MySQLConnectionAbstract(ABC):
         self._ssl_verify_cert: Optional[bool] = ssl_verify_cert
         self._ssl_verify_identity: Optional[bool] = ssl_verify_identity
         self._tls_versions: Optional[List[str]] = tls_versions
-        self._tls_ciphersuites: Optional[List[str]] = []
+        self._tls_ciphersuites: Optional[List[str]] = tls_ciphersuites
         self._auth_plugin: Optional[str] = auth_plugin
         self._auth_plugin_class: Optional[str] = None
         self._handshake: Optional[HandShakeType] = None
@@ -239,7 +250,7 @@ class MySQLConnectionAbstract(ABC):
             loop or asyncio.get_event_loop()
         )
         self._client_flags: int = client_flags or ClientFlag.get_default()
-        self._server_info: ServerInfo
+        self._server_info: Optional[ServerInfo] = None
         self._cursors: weakref.WeakSet = weakref.WeakSet()
         self._query_attrs: Dict[str, BinaryProtocolType] = {}
         self._query_attrs_supported: int = False
@@ -255,16 +266,15 @@ class MySQLConnectionAbstract(ABC):
         self.raise_on_warnings: bool = raise_on_warnings
         self._buffered: bool = buffered
         self._raw: bool = raw
+        self._use_unicode: bool = use_unicode
         self._have_next_result: bool = False
         self._unread_result: bool = False
-        self._use_unicode: bool = True
         self._in_transaction: bool = False
         self._oci_config_file: Optional[str] = None
         self._oci_config_profile: Optional[str] = None
-        self._fido_callback: Optional[Union[str, Callable[[str], None]]] = fido_callback
-        self._webauthn_callback: Optional[
-            Union[str, Callable[[str], None]]
-        ] = webauthn_callback
+        self._webauthn_callback: Optional[Union[str, Callable[[str], None]]] = (
+            webauthn_callback
+        )
 
         self.converter: Optional[MySQLConverter] = None
 
@@ -339,10 +349,10 @@ class MySQLConnectionAbstract(ABC):
                 raise AttributeError(
                     "ssl_key and ssl_cert need to be both set, or neither"
                 )
-            if self._tls_versions:
+            if self._tls_versions is not None:
                 self._validate_tls_versions()
 
-            if self._tls_ciphersuites:
+            if self._tls_ciphersuites is not None:
                 self._validate_tls_ciphersuites()
 
         if not isinstance(self._connection_attrs, dict):
@@ -417,15 +427,6 @@ class MySQLConnectionAbstract(ABC):
                     KRB_SERVICE_PINCIPAL_ERROR.format(error="is incorrectly formatted")
                 )
 
-        if self._fido_callback:
-            warn_msg = (
-                "The `fido_callback` connection argument is deprecated and it will be "
-                "removed in a future release of MySQL Connector/Python. "
-                "Use `webauth_callback` instead"
-            )
-            warnings.warn(warn_msg, DeprecationWarning)
-            self._validate_callable("fido_callback", self._fido_callback, 1)
-
         if self._webauthn_callback:
             self._validate_callable("webauth_callback", self._webauthn_callback, 1)
 
@@ -465,7 +466,7 @@ class MySQLConnectionAbstract(ABC):
         # an older version.
         tls_versions.sort(reverse=True)
         newer_tls_ver = tls_versions[0]
-        # translated_names[0] belongs to TLSv1, TLSv1.1 and TLSv1.2
+        # translated_names[0] are TLSv1.2 only
         # translated_names[1] are TLSv1.3 only
         translated_names: List[List[str]] = [[], []]
         iani_cipher_suites_names = {}
@@ -505,6 +506,18 @@ class MySQLConnectionAbstract(ABC):
                 "No valid cipher suite found in the 'tls_ciphersuites' list"
             )
 
+        # raise an error when using an unacceptable cipher
+        for cipher_as_ossl in translated_names[0]:
+            if cipher_as_ossl in UNACCEPTABLE_TLS_CIPHERSUITES["TLSv1.2"].values():
+                raise NotSupportedError(
+                    f"Cipher {cipher_as_ossl} when used with TLSv1.2 is unacceptable."
+                )
+        for cipher_as_ossl in translated_names[1]:
+            if cipher_as_ossl in UNACCEPTABLE_TLS_CIPHERSUITES["TLSv1.3"].values():
+                raise NotSupportedError(
+                    f"Cipher {cipher_as_ossl} when used with TLSv1.3 is unacceptable."
+                )
+
         self._tls_ciphersuites = [
             ":".join(translated_names[0]),
             ":".join(translated_names[1]),
@@ -566,13 +579,13 @@ class MySQLConnectionAbstract(ABC):
             )
 
         use_tls_versions = []
-        deprecated_tls_versions = []
+        unacceptable_tls_versions = []
         invalid_tls_versions = []
         for tls_ver in tls_versions:
             if tls_ver in TLS_VERSIONS:
                 use_tls_versions.append(tls_ver)
-            if tls_ver in DEPRECATED_TLS_VERSIONS:
-                deprecated_tls_versions.append(tls_ver)
+            if tls_ver in UNACCEPTABLE_TLS_VERSIONS:
+                unacceptable_tls_versions.append(tls_ver)
             else:
                 invalid_tls_versions.append(tls_ver)
 
@@ -581,12 +594,11 @@ class MySQLConnectionAbstract(ABC):
                 raise NotSupportedError(
                     TLS_VER_NO_SUPPORTED.format(tls_version, TLS_VERSIONS)
                 )
-            use_tls_versions.sort()
             self._tls_versions = use_tls_versions
-        elif deprecated_tls_versions:
+        elif unacceptable_tls_versions:
             raise NotSupportedError(
-                TLS_VERSION_DEPRECATED_ERROR.format(
-                    deprecated_tls_versions, TLS_VERSIONS
+                TLS_VERSION_UNACCEPTABLE_ERROR.format(
+                    unacceptable_tls_versions, TLS_VERSIONS
                 )
             )
         elif invalid_tls_versions:
@@ -892,6 +904,18 @@ class MySQLConnectionAbstract(ABC):
             raise ValueError("Expected a boolean type")
         self._unread_result = value
 
+    @property
+    def collation(self) -> str:
+        """Returns the collation for current connection.
+
+        This property returns the collation name of the current connection.
+        The server is queried when the connection is active. If not connected,
+        the configured collation name is returned.
+
+        Returns a string.
+        """
+        return self._charset.collation
+
     @property
     def charset(self) -> str:
         """Return the character set for current connection.
@@ -900,7 +924,40 @@ class MySQLConnectionAbstract(ABC):
         The server is queried when the connection is active.
         If not connected, the configured character set name is returned.
         """
-        return self._charset.name if self._charset else "utf8"
+        return self._charset.name
+
+    @property
+    def charset_id(self) -> int:
+        """The charset ID utilized during the connection phase.
+
+        If the charset ID hasn't been set, the default charset ID is returned.
+        """
+        return self._charset.charset_id
+
+    @property
+    def _charset(self) -> Charset:
+        """The charset object encapsulates charset and collation information."""
+        if self.__charset is None:
+            if self._server_info is None:
+                # We mustn't set `_charset`  since we still don't know
+                # the server version. We temporarily return the default
+                # charset for undefined scenarios - eventually, the server
+                # info will be available and `_charset` (data class) will be set.
+                return charsets.get_by_id(MYSQL_DEFAULT_CHARSET_ID_57)
+
+            self.__charset = charsets.get_by_id(
+                (
+                    MYSQL_DEFAULT_CHARSET_ID_57
+                    if self._server_info.version_tuple < (8, 0)
+                    else MYSQL_DEFAULT_CHARSET_ID_80
+                )
+            )
+        return self.__charset
+
+    @_charset.setter
+    def _charset(self, value: Charset) -> None:
+        """The charset object encapsulates charset and collation information."""
+        self.__charset = value
 
     @property
     def python_charset(self) -> str:
@@ -939,7 +996,7 @@ class MySQLConnectionAbstract(ABC):
         Some setting like autocommit, character set, and SQL mode are set using this
         method.
         """
-        await self.set_charset_collation(self._charset.charset_id)
+        await self.set_charset_collation(charset=self._charset.charset_id)
         await self.set_autocommit(self._autocommit)
         if self._time_zone:
             await self.set_time_zone(self._time_zone)
@@ -999,18 +1056,9 @@ class MySQLConnectionAbstract(ABC):
             charset = DEFAULT_CONFIGURATION["charset"]
             self._charset = charsets.get_by_name(charset)  # type: ignore[arg-type]
 
-        self._charset_name = self._charset.name
-        self._charset_collation = self._charset.collation
-
         await self.cmd_query(
             f"SET NAMES '{self._charset.name}' COLLATE '{self._charset.collation}'"
         )
-        try:
-            # Required for C Extension
-            self.set_character_set_name(self._charset.name)
-        except AttributeError:
-            # Not required for pure Python connection
-            pass
 
         if self.converter:
             self.converter.set_charset(self._charset.name)
@@ -1047,7 +1095,9 @@ class MySQLConnectionAbstract(ABC):
             The MySQL server version as a tuple. If not previously connected, it will
             return `None`.
         """
-        return self._server_info.version  # type: ignore[return-value]
+        if self._server_info is not None:
+            return self._server_info.version  # type: ignore[return-value]
+        return None
 
     def get_server_info(self) -> Optional[str]:
         """Gets the original MySQL version information.
@@ -1288,7 +1338,7 @@ class MySQLConnectionAbstract(ABC):
 
         Raises:
             ProgrammingError: When cursor_class is not a subclass of
-                              CursorBase.
+                              MySQLCursor.
             ValueError: When cursor is not available.
         """
 
@@ -1507,6 +1557,51 @@ class MySQLConnectionAbstract(ABC):
         with OK packet information.
         """
 
+    @abstractmethod
+    async def cmd_change_user(
+        self,
+        username: str = "",
+        password: str = "",
+        database: str = "",
+        charset: Optional[int] = None,
+        password1: str = "",
+        password2: str = "",
+        password3: str = "",
+        oci_config_file: str = "",
+        oci_config_profile: str = "",
+    ) -> Optional[OkPacketType]:
+        """Changes the current logged in user.
+
+        It also causes the specified database to become the default (current)
+        database. It is also possible to change the character set using the
+        charset argument. The character set passed during initial connection
+        is reused if no value of charset is passed via this method.
+
+        Args:
+            username: New account's username.
+            password: New account's password.
+            database: Database to become the default (current) database.
+            charset: Client charset (see [1]), only the lower 8-bits.
+            password1: New account's password factor 1 - it's used instead
+                       of `password` if set (higher precedence).
+            password2: New account's password factor 2.
+            password3: New account's password factor 3.
+            oci_config_file: OCI configuration file location (path-like string).
+            oci_config_profile: OCI configuration profile location (path-like string).
+
+        Returns:
+            ok_packet: Dictionary containing the OK packet information.
+
+        Examples:
+            ```
+            >>> cnx.cmd_change_user(username='', password='', database='', charset=33)
+            ```
+
+        References:
+            [1]: https://dev.mysql.com/doc/dev/mysql-server/latest/\
+                page_protocol_basic_character_set.html#a_protocol_character_set
+        """
+
 
 class MySQLCursorAbstract(ABC):
     """Defines the MySQL cursor interface."""
@@ -1772,8 +1867,6 @@ class MySQLCursorAbstract(ABC):
         Returns:
             List of existing query attributes.
         """
-        if hasattr(self, "_cnx"):
-            return self._cnx.query_attrs
         if hasattr(self, "_connection"):
             return self._connection.query_attrs
         return None
@@ -1821,7 +1914,6 @@ class MySQLCursorAbstract(ABC):
 
 
 class CMySQLPrepStmt(GenericWrapper):
-
     """Structure to represent a result from `CMySQLConnection.cmd_stmt_prepare`.
     It can be used consistently as a type hint.
 
