@@ -45,6 +45,8 @@ MYSQL_VECTOR_TYPE_CODE = "f"
 """Expected `typecode` when decoding VECTOR values from
 MySQL (blob) to Python (array.array).
 """
+MYSQL_DEFAULT_CHARSET_ID_57 = 45
+MYSQL_DEFAULT_CHARSET_ID_80 = 255
 
 DEFAULT_CONFIGURATION: Dict[str, Optional[Union[str, bool, int]]] = {
     "database": None,
@@ -102,10 +104,191 @@ DEFAULT_CONFIGURATION: Dict[str, Optional[Union[str, bool, int]]] = {
 
 CNX_POOL_ARGS: Tuple[str, str, str] = ("pool_name", "pool_size", "pool_reset_session")
 
+CONN_ATTRS_DN: Tuple[str, ...] = (
+    "_pid",
+    "_platform",
+    "_source_host",
+    "_client_name",
+    "_client_license",
+    "_client_version",
+    "_os",
+    "_connector_name",
+    "_connector_license",
+    "_connector_version",
+)
+
+# List of deprecated cursor class names
+DEPRECATED_CURSOR_CLASS_NAMES: Tuple[str, ...] = (
+    "MySQLCursorPreparedRaw",
+    "MySQLCursorNamedTuple",
+    "MySQLCursorBufferedNamedTuple",
+    "MySQLCursorPreparedNamedTuple",
+    "CMySQLCursorPreparedRaw",
+    "CMySQLCursorNamedTuple",
+    "CMySQLCursorBufferedNamedTuple",
+    "CMySQLCursorPreparedNamedTuple",
+)
 
 TLS_VERSIONS: List[str] = APPROVED_TLS_VERSIONS + DEPRECATED_TLS_VERSIONS
 """Accepted TLS versions. A warning is raised when using a deprecated version."""
 
+# TLS v1.2 cipher suites IANI to OpenSSL name translation
+TLSV1_2_CIPHER_SUITES: Dict[str, str] = {
+    "TLS_RSA_WITH_NULL_SHA256": "NULL-SHA256",
+    "TLS_RSA_WITH_AES_128_CBC_SHA256": "AES128-SHA256",
+    "TLS_RSA_WITH_AES_256_CBC_SHA256": "AES256-SHA256",
+    "TLS_RSA_WITH_AES_128_GCM_SHA256": "AES128-GCM-SHA256",
+    "TLS_RSA_WITH_AES_256_GCM_SHA384": "AES256-GCM-SHA384",
+    "TLS_DH_RSA_WITH_AES_128_CBC_SHA256": "DH-RSA-AES128-SHA256",
+    "TLS_DH_RSA_WITH_AES_256_CBC_SHA256": "DH-RSA-AES256-SHA256",
+    "TLS_DH_RSA_WITH_AES_128_GCM_SHA256": "DH-RSA-AES128-GCM-SHA256",
+    "TLS_DH_RSA_WITH_AES_256_GCM_SHA384": "DH-RSA-AES256-GCM-SHA384",
+    "TLS_DH_DSS_WITH_AES_128_CBC_SHA256": "DH-DSS-AES128-SHA256",
+    "TLS_DH_DSS_WITH_AES_256_CBC_SHA256": "DH-DSS-AES256-SHA256",
+    "TLS_DH_DSS_WITH_AES_128_GCM_SHA256": "DH-DSS-AES128-GCM-SHA256",
+    "TLS_DH_DSS_WITH_AES_256_GCM_SHA384": "DH-DSS-AES256-GCM-SHA384",
+    "TLS_DHE_RSA_WITH_AES_128_CBC_SHA256": "DHE-RSA-AES128-SHA256",
+    "TLS_DHE_RSA_WITH_AES_256_CBC_SHA256": "DHE-RSA-AES256-SHA256",
+    "TLS_DHE_RSA_WITH_AES_128_GCM_SHA256": "DHE-RSA-AES128-GCM-SHA256",
+    "TLS_DHE_RSA_WITH_AES_256_GCM_SHA384": "DHE-RSA-AES256-GCM-SHA384",
+    "TLS_DHE_DSS_WITH_AES_128_CBC_SHA256": "DHE-DSS-AES128-SHA256",
+    "TLS_DHE_DSS_WITH_AES_256_CBC_SHA256": "DHE-DSS-AES256-SHA256",
+    "TLS_DHE_DSS_WITH_AES_128_GCM_SHA256": "DHE-DSS-AES128-GCM-SHA256",
+    "TLS_DHE_DSS_WITH_AES_256_GCM_SHA384": "DHE-DSS-AES256-GCM-SHA384",
+    "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256": "ECDHE-RSA-AES128-SHA256",
+    "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384": "ECDHE-RSA-AES256-SHA384",
+    "TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256": "ECDHE-RSA-AES128-GCM-SHA256",
+    "TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384": "ECDHE-RSA-AES256-GCM-SHA384",
+    "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256": "ECDHE-ECDSA-AES128-SHA256",
+    "TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384": "ECDHE-ECDSA-AES256-SHA384",
+    "TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256": "ECDHE-ECDSA-AES128-GCM-SHA256",
+    "TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384": "ECDHE-ECDSA-AES256-GCM-SHA384",
+    "TLS_DH_anon_WITH_AES_128_CBC_SHA256": "ADH-AES128-SHA256",
+    "TLS_DH_anon_WITH_AES_256_CBC_SHA256": "ADH-AES256-SHA256",
+    "TLS_DH_anon_WITH_AES_128_GCM_SHA256": "ADH-AES128-GCM-SHA256",
+    "TLS_DH_anon_WITH_AES_256_GCM_SHA384": "ADH-AES256-GCM-SHA384",
+    "RSA_WITH_AES_128_CCM": "AES128-CCM",
+    "RSA_WITH_AES_256_CCM": "AES256-CCM",
+    "DHE_RSA_WITH_AES_128_CCM": "DHE-RSA-AES128-CCM",
+    "DHE_RSA_WITH_AES_256_CCM": "DHE-RSA-AES256-CCM",
+    "RSA_WITH_AES_128_CCM_8": "AES128-CCM8",
+    "RSA_WITH_AES_256_CCM_8": "AES256-CCM8",
+    "DHE_RSA_WITH_AES_128_CCM_8": "DHE-RSA-AES128-CCM8",
+    "DHE_RSA_WITH_AES_256_CCM_8": "DHE-RSA-AES256-CCM8",
+    "ECDHE_ECDSA_WITH_AES_128_CCM": "ECDHE-ECDSA-AES128-CCM",
+    "ECDHE_ECDSA_WITH_AES_256_CCM": "ECDHE-ECDSA-AES256-CCM",
+    "ECDHE_ECDSA_WITH_AES_128_CCM_8": "ECDHE-ECDSA-AES128-CCM8",
+    "ECDHE_ECDSA_WITH_AES_256_CCM_8": "ECDHE-ECDSA-AES256-CCM8",
+    # ARIA cipher suites from RFC6209, extending TLS v1.2
+    "TLS_RSA_WITH_ARIA_128_GCM_SHA256": "ARIA128-GCM-SHA256",
+    "TLS_RSA_WITH_ARIA_256_GCM_SHA384": "ARIA256-GCM-SHA384",
+    "TLS_DHE_RSA_WITH_ARIA_128_GCM_SHA256": "DHE-RSA-ARIA128-GCM-SHA256",
+    "TLS_DHE_RSA_WITH_ARIA_256_GCM_SHA384": "DHE-RSA-ARIA256-GCM-SHA384",
+    "TLS_DHE_DSS_WITH_ARIA_128_GCM_SHA256": "DHE-DSS-ARIA128-GCM-SHA256",
+    "TLS_DHE_DSS_WITH_ARIA_256_GCM_SHA384": "DHE-DSS-ARIA256-GCM-SHA384",
+    "TLS_ECDHE_ECDSA_WITH_ARIA_128_GCM_SHA256": "ECDHE-ECDSA-ARIA128-GCM-SHA256",
+    "TLS_ECDHE_ECDSA_WITH_ARIA_256_GCM_SHA384": "ECDHE-ECDSA-ARIA256-GCM-SHA384",
+    "TLS_ECDHE_RSA_WITH_ARIA_128_GCM_SHA256": "ECDHE-ARIA128-GCM-SHA256",
+    "TLS_ECDHE_RSA_WITH_ARIA_256_GCM_SHA384": "ECDHE-ARIA256-GCM-SHA384",
+    "TLS_PSK_WITH_ARIA_128_GCM_SHA256": "PSK-ARIA128-GCM-SHA256",
+    "TLS_PSK_WITH_ARIA_256_GCM_SHA384": "PSK-ARIA256-GCM-SHA384",
+    "TLS_DHE_PSK_WITH_ARIA_128_GCM_SHA256": "DHE-PSK-ARIA128-GCM-SHA256",
+    "TLS_DHE_PSK_WITH_ARIA_256_GCM_SHA384": "DHE-PSK-ARIA256-GCM-SHA384",
+    "TLS_RSA_PSK_WITH_ARIA_128_GCM_SHA256": "RSA-PSK-ARIA128-GCM-SHA256",
+    "TLS_RSA_PSK_WITH_ARIA_256_GCM_SHA384": "RSA-PSK-ARIA256-GCM-SHA384",
+    # Camellia HMAC-Based cipher suites from RFC6367, extending TLS v1.2
+    "TLS_ECDHE_ECDSA_WITH_CAMELLIA_128_CBC_SHA256": "ECDHE-ECDSA-CAMELLIA128-SHA256",
+    "TLS_ECDHE_ECDSA_WITH_CAMELLIA_256_CBC_SHA384": "ECDHE-ECDSA-CAMELLIA256-SHA384",
+    "TLS_ECDHE_RSA_WITH_CAMELLIA_128_CBC_SHA256": "ECDHE-RSA-CAMELLIA128-SHA256",
+    "TLS_ECDHE_RSA_WITH_CAMELLIA_256_CBC_SHA384": "ECDHE-RSA-CAMELLIA256-SHA384",
+    # Pre-shared keying (PSK) cipher suites",
+    "PSK_WITH_NULL_SHA": "PSK-NULL-SHA",
+    "DHE_PSK_WITH_NULL_SHA": "DHE-PSK-NULL-SHA",
+    "RSA_PSK_WITH_NULL_SHA": "RSA-PSK-NULL-SHA",
+    "PSK_WITH_RC4_128_SHA": "PSK-RC4-SHA",
+    "PSK_WITH_3DES_EDE_CBC_SHA": "PSK-3DES-EDE-CBC-SHA",
+    "PSK_WITH_AES_128_CBC_SHA": "PSK-AES128-CBC-SHA",
+    "PSK_WITH_AES_256_CBC_SHA": "PSK-AES256-CBC-SHA",
+    "DHE_PSK_WITH_RC4_128_SHA": "DHE-PSK-RC4-SHA",
+    "DHE_PSK_WITH_3DES_EDE_CBC_SHA": "DHE-PSK-3DES-EDE-CBC-SHA",
+    "DHE_PSK_WITH_AES_128_CBC_SHA": "DHE-PSK-AES128-CBC-SHA",
+    "DHE_PSK_WITH_AES_256_CBC_SHA": "DHE-PSK-AES256-CBC-SHA",
+    "RSA_PSK_WITH_RC4_128_SHA": "RSA-PSK-RC4-SHA",
+    "RSA_PSK_WITH_3DES_EDE_CBC_SHA": "RSA-PSK-3DES-EDE-CBC-SHA",
+    "RSA_PSK_WITH_AES_128_CBC_SHA": "RSA-PSK-AES128-CBC-SHA",
+    "RSA_PSK_WITH_AES_256_CBC_SHA": "RSA-PSK-AES256-CBC-SHA",
+    "PSK_WITH_AES_128_GCM_SHA256": "PSK-AES128-GCM-SHA256",
+    "PSK_WITH_AES_256_GCM_SHA384": "PSK-AES256-GCM-SHA384",
+    "DHE_PSK_WITH_AES_128_GCM_SHA256": "DHE-PSK-AES128-GCM-SHA256",
+    "DHE_PSK_WITH_AES_256_GCM_SHA384": "DHE-PSK-AES256-GCM-SHA384",
+    "RSA_PSK_WITH_AES_128_GCM_SHA256": "RSA-PSK-AES128-GCM-SHA256",
+    "RSA_PSK_WITH_AES_256_GCM_SHA384": "RSA-PSK-AES256-GCM-SHA384",
+    "PSK_WITH_AES_128_CBC_SHA256": "PSK-AES128-CBC-SHA256",
+    "PSK_WITH_AES_256_CBC_SHA384": "PSK-AES256-CBC-SHA384",
+    "PSK_WITH_NULL_SHA256": "PSK-NULL-SHA256",
+    "PSK_WITH_NULL_SHA384": "PSK-NULL-SHA384",
+    "DHE_PSK_WITH_AES_128_CBC_SHA256": "DHE-PSK-AES128-CBC-SHA256",
+    "DHE_PSK_WITH_AES_256_CBC_SHA384": "DHE-PSK-AES256-CBC-SHA384",
+    "DHE_PSK_WITH_NULL_SHA256": "DHE-PSK-NULL-SHA256",
+    "DHE_PSK_WITH_NULL_SHA384": "DHE-PSK-NULL-SHA384",
+    "RSA_PSK_WITH_AES_128_CBC_SHA256": "RSA-PSK-AES128-CBC-SHA256",
+    "RSA_PSK_WITH_AES_256_CBC_SHA384": "RSA-PSK-AES256-CBC-SHA384",
+    "RSA_PSK_WITH_NULL_SHA256": "RSA-PSK-NULL-SHA256",
+    "RSA_PSK_WITH_NULL_SHA384": "RSA-PSK-NULL-SHA384",
+    "ECDHE_PSK_WITH_RC4_128_SHA": "ECDHE-PSK-RC4-SHA",
+    "ECDHE_PSK_WITH_3DES_EDE_CBC_SHA": "ECDHE-PSK-3DES-EDE-CBC-SHA",
+    "ECDHE_PSK_WITH_AES_128_CBC_SHA": "ECDHE-PSK-AES128-CBC-SHA",
+    "ECDHE_PSK_WITH_AES_256_CBC_SHA": "ECDHE-PSK-AES256-CBC-SHA",
+    "ECDHE_PSK_WITH_AES_128_CBC_SHA256": "ECDHE-PSK-AES128-CBC-SHA256",
+    "ECDHE_PSK_WITH_AES_256_CBC_SHA384": "ECDHE-PSK-AES256-CBC-SHA384",
+    "ECDHE_PSK_WITH_NULL_SHA": "ECDHE-PSK-NULL-SHA",
+    "ECDHE_PSK_WITH_NULL_SHA256": "ECDHE-PSK-NULL-SHA256",
+    "ECDHE_PSK_WITH_NULL_SHA384": "ECDHE-PSK-NULL-SHA384",
+    "PSK_WITH_CAMELLIA_128_CBC_SHA256": "PSK-CAMELLIA128-SHA256",
+    "PSK_WITH_CAMELLIA_256_CBC_SHA384": "PSK-CAMELLIA256-SHA384",
+    "DHE_PSK_WITH_CAMELLIA_128_CBC_SHA256": "DHE-PSK-CAMELLIA128-SHA256",
+    "DHE_PSK_WITH_CAMELLIA_256_CBC_SHA384": "DHE-PSK-CAMELLIA256-SHA384",
+    "RSA_PSK_WITH_CAMELLIA_128_CBC_SHA256": "RSA-PSK-CAMELLIA128-SHA256",
+    "RSA_PSK_WITH_CAMELLIA_256_CBC_SHA384": "RSA-PSK-CAMELLIA256-SHA384",
+    "ECDHE_PSK_WITH_CAMELLIA_128_CBC_SHA256": "ECDHE-PSK-CAMELLIA128-SHA256",
+    "ECDHE_PSK_WITH_CAMELLIA_256_CBC_SHA384": "ECDHE-PSK-CAMELLIA256-SHA384",
+    "PSK_WITH_AES_128_CCM": "PSK-AES128-CCM",
+    "PSK_WITH_AES_256_CCM": "PSK-AES256-CCM",
+    "DHE_PSK_WITH_AES_128_CCM": "DHE-PSK-AES128-CCM",
+    "DHE_PSK_WITH_AES_256_CCM": "DHE-PSK-AES256-CCM",
+    "PSK_WITH_AES_128_CCM_8": "PSK-AES128-CCM8",
+    "PSK_WITH_AES_256_CCM_8": "PSK-AES256-CCM8",
+    "DHE_PSK_WITH_AES_128_CCM_8": "DHE-PSK-AES128-CCM8",
+    "DHE_PSK_WITH_AES_256_CCM_8": "DHE-PSK-AES256-CCM8",
+    # ChaCha20-Poly1305 cipher suites, extending TLS v1.2
+    "TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256": "ECDHE-RSA-CHACHA20-POLY1305",
+    "TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256": "ECDHE-ECDSA-CHACHA20-POLY1305",
+    "TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256": "DHE-RSA-CHACHA20-POLY1305",
+    "TLS_PSK_WITH_CHACHA20_POLY1305_SHA256": "PSK-CHACHA20-POLY1305",
+    "TLS_ECDHE_PSK_WITH_CHACHA20_POLY1305_SHA256": "ECDHE-PSK-CHACHA20-POLY1305",
+    "TLS_DHE_PSK_WITH_CHACHA20_POLY1305_SHA256": "DHE-PSK-CHACHA20-POLY1305",
+    "TLS_RSA_PSK_WITH_CHACHA20_POLY1305_SHA256": "RSA-PSK-CHACHA20-POLY1305",
+}
+
+# TLS v1.3 cipher suites IANI to OpenSSL name translation
+TLSV1_3_CIPHER_SUITES: Dict[str, str] = {
+    "TLS_AES_128_GCM_SHA256": "TLS_AES_128_GCM_SHA256",
+    "TLS_AES_256_GCM_SHA384": "TLS_AES_256_GCM_SHA384",
+    "TLS_CHACHA20_POLY1305_SHA256": "TLS_CHACHA20_POLY1305_SHA256",
+    "TLS_AES_128_CCM_SHA256": "TLS_AES_128_CCM_SHA256",
+    "TLS_AES_128_CCM_8_SHA256": "TLS_AES_128_CCM_8_SHA256",
+}
+
+TLS_CIPHER_SUITES: Dict[str, Dict[str, str]] = {
+    "TLSv1.2": TLSV1_2_CIPHER_SUITES,
+    "TLSv1.3": TLSV1_3_CIPHER_SUITES,
+}
+
+OPENSSL_CS_NAMES: Dict[str, ValuesView[str]] = {
+    "TLSv1.2": TLSV1_2_CIPHER_SUITES.values(),
+    "TLSv1.3": TLSV1_3_CIPHER_SUITES.values(),
+}
+
 
 def flag_is_set(flag: int, flags: int) -> bool:
     """Checks if the flag is set
@@ -134,6 +317,28 @@ def _obsolete_option(name: str, new_name: str, value: int) -> int:
     return value
 
 
+def raise_warning_against_deprecated_cursor_class(
+    cursor_name: str,
+) -> None:
+    """Raise a deprecation warning if the cursor class name matches against
+    any of DEPRECATED_CURSOR_CLASS_NAMES list.
+
+    Args:
+        cursor_name (str):  cursor class name to be checked against
+                            DEPRECATED_CURSOR_CLASS_NAMES list.
+    Returns:
+        None
+    """
+    if cursor_name in DEPRECATED_CURSOR_CLASS_NAMES:
+        warnings.warn(
+            message=f"WARNING: Cursor type {cursor_name} is now "
+            "deprecated and will be removed in a future release of "
+            "MySQL Connector/Python.",
+            category=DeprecationWarning,
+            stacklevel=3,
+        )
+
+
 class _Constants(ABC):
     """Base class for constants."""
 
@@ -961,175 +1166,3 @@ class SQLMode(_Constants):
             if not key.startswith("_") and not hasattr(getattr(cls, key), "__call__"):
                 res.append(key)
         return tuple(sorted(res))
-
-
-CONN_ATTRS_DN: List[str] = [
-    "_pid",
-    "_platform",
-    "_source_host",
-    "_client_name",
-    "_client_license",
-    "_client_version",
-    "_os",
-    "_connector_name",
-    "_connector_license",
-    "_connector_version",
-]
-
-
-# TLS v1.2 cipher suites IANI to OpenSSL name translation
-TLSV1_2_CIPHER_SUITES: Dict[str, str] = {
-    "TLS_RSA_WITH_NULL_SHA256": "NULL-SHA256",
-    "TLS_RSA_WITH_AES_128_CBC_SHA256": "AES128-SHA256",
-    "TLS_RSA_WITH_AES_256_CBC_SHA256": "AES256-SHA256",
-    "TLS_RSA_WITH_AES_128_GCM_SHA256": "AES128-GCM-SHA256",
-    "TLS_RSA_WITH_AES_256_GCM_SHA384": "AES256-GCM-SHA384",
-    "TLS_DH_RSA_WITH_AES_128_CBC_SHA256": "DH-RSA-AES128-SHA256",
-    "TLS_DH_RSA_WITH_AES_256_CBC_SHA256": "DH-RSA-AES256-SHA256",
-    "TLS_DH_RSA_WITH_AES_128_GCM_SHA256": "DH-RSA-AES128-GCM-SHA256",
-    "TLS_DH_RSA_WITH_AES_256_GCM_SHA384": "DH-RSA-AES256-GCM-SHA384",
-    "TLS_DH_DSS_WITH_AES_128_CBC_SHA256": "DH-DSS-AES128-SHA256",
-    "TLS_DH_DSS_WITH_AES_256_CBC_SHA256": "DH-DSS-AES256-SHA256",
-    "TLS_DH_DSS_WITH_AES_128_GCM_SHA256": "DH-DSS-AES128-GCM-SHA256",
-    "TLS_DH_DSS_WITH_AES_256_GCM_SHA384": "DH-DSS-AES256-GCM-SHA384",
-    "TLS_DHE_RSA_WITH_AES_128_CBC_SHA256": "DHE-RSA-AES128-SHA256",
-    "TLS_DHE_RSA_WITH_AES_256_CBC_SHA256": "DHE-RSA-AES256-SHA256",
-    "TLS_DHE_RSA_WITH_AES_128_GCM_SHA256": "DHE-RSA-AES128-GCM-SHA256",
-    "TLS_DHE_RSA_WITH_AES_256_GCM_SHA384": "DHE-RSA-AES256-GCM-SHA384",
-    "TLS_DHE_DSS_WITH_AES_128_CBC_SHA256": "DHE-DSS-AES128-SHA256",
-    "TLS_DHE_DSS_WITH_AES_256_CBC_SHA256": "DHE-DSS-AES256-SHA256",
-    "TLS_DHE_DSS_WITH_AES_128_GCM_SHA256": "DHE-DSS-AES128-GCM-SHA256",
-    "TLS_DHE_DSS_WITH_AES_256_GCM_SHA384": "DHE-DSS-AES256-GCM-SHA384",
-    "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256": "ECDHE-RSA-AES128-SHA256",
-    "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384": "ECDHE-RSA-AES256-SHA384",
-    "TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256": "ECDHE-RSA-AES128-GCM-SHA256",
-    "TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384": "ECDHE-RSA-AES256-GCM-SHA384",
-    "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256": "ECDHE-ECDSA-AES128-SHA256",
-    "TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384": "ECDHE-ECDSA-AES256-SHA384",
-    "TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256": "ECDHE-ECDSA-AES128-GCM-SHA256",
-    "TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384": "ECDHE-ECDSA-AES256-GCM-SHA384",
-    "TLS_DH_anon_WITH_AES_128_CBC_SHA256": "ADH-AES128-SHA256",
-    "TLS_DH_anon_WITH_AES_256_CBC_SHA256": "ADH-AES256-SHA256",
-    "TLS_DH_anon_WITH_AES_128_GCM_SHA256": "ADH-AES128-GCM-SHA256",
-    "TLS_DH_anon_WITH_AES_256_GCM_SHA384": "ADH-AES256-GCM-SHA384",
-    "RSA_WITH_AES_128_CCM": "AES128-CCM",
-    "RSA_WITH_AES_256_CCM": "AES256-CCM",
-    "DHE_RSA_WITH_AES_128_CCM": "DHE-RSA-AES128-CCM",
-    "DHE_RSA_WITH_AES_256_CCM": "DHE-RSA-AES256-CCM",
-    "RSA_WITH_AES_128_CCM_8": "AES128-CCM8",
-    "RSA_WITH_AES_256_CCM_8": "AES256-CCM8",
-    "DHE_RSA_WITH_AES_128_CCM_8": "DHE-RSA-AES128-CCM8",
-    "DHE_RSA_WITH_AES_256_CCM_8": "DHE-RSA-AES256-CCM8",
-    "ECDHE_ECDSA_WITH_AES_128_CCM": "ECDHE-ECDSA-AES128-CCM",
-    "ECDHE_ECDSA_WITH_AES_256_CCM": "ECDHE-ECDSA-AES256-CCM",
-    "ECDHE_ECDSA_WITH_AES_128_CCM_8": "ECDHE-ECDSA-AES128-CCM8",
-    "ECDHE_ECDSA_WITH_AES_256_CCM_8": "ECDHE-ECDSA-AES256-CCM8",
-    # ARIA cipher suites from RFC6209, extending TLS v1.2
-    "TLS_RSA_WITH_ARIA_128_GCM_SHA256": "ARIA128-GCM-SHA256",
-    "TLS_RSA_WITH_ARIA_256_GCM_SHA384": "ARIA256-GCM-SHA384",
-    "TLS_DHE_RSA_WITH_ARIA_128_GCM_SHA256": "DHE-RSA-ARIA128-GCM-SHA256",
-    "TLS_DHE_RSA_WITH_ARIA_256_GCM_SHA384": "DHE-RSA-ARIA256-GCM-SHA384",
-    "TLS_DHE_DSS_WITH_ARIA_128_GCM_SHA256": "DHE-DSS-ARIA128-GCM-SHA256",
-    "TLS_DHE_DSS_WITH_ARIA_256_GCM_SHA384": "DHE-DSS-ARIA256-GCM-SHA384",
-    "TLS_ECDHE_ECDSA_WITH_ARIA_128_GCM_SHA256": "ECDHE-ECDSA-ARIA128-GCM-SHA256",
-    "TLS_ECDHE_ECDSA_WITH_ARIA_256_GCM_SHA384": "ECDHE-ECDSA-ARIA256-GCM-SHA384",
-    "TLS_ECDHE_RSA_WITH_ARIA_128_GCM_SHA256": "ECDHE-ARIA128-GCM-SHA256",
-    "TLS_ECDHE_RSA_WITH_ARIA_256_GCM_SHA384": "ECDHE-ARIA256-GCM-SHA384",
-    "TLS_PSK_WITH_ARIA_128_GCM_SHA256": "PSK-ARIA128-GCM-SHA256",
-    "TLS_PSK_WITH_ARIA_256_GCM_SHA384": "PSK-ARIA256-GCM-SHA384",
-    "TLS_DHE_PSK_WITH_ARIA_128_GCM_SHA256": "DHE-PSK-ARIA128-GCM-SHA256",
-    "TLS_DHE_PSK_WITH_ARIA_256_GCM_SHA384": "DHE-PSK-ARIA256-GCM-SHA384",
-    "TLS_RSA_PSK_WITH_ARIA_128_GCM_SHA256": "RSA-PSK-ARIA128-GCM-SHA256",
-    "TLS_RSA_PSK_WITH_ARIA_256_GCM_SHA384": "RSA-PSK-ARIA256-GCM-SHA384",
-    # Camellia HMAC-Based cipher suites from RFC6367, extending TLS v1.2
-    "TLS_ECDHE_ECDSA_WITH_CAMELLIA_128_CBC_SHA256": "ECDHE-ECDSA-CAMELLIA128-SHA256",
-    "TLS_ECDHE_ECDSA_WITH_CAMELLIA_256_CBC_SHA384": "ECDHE-ECDSA-CAMELLIA256-SHA384",
-    "TLS_ECDHE_RSA_WITH_CAMELLIA_128_CBC_SHA256": "ECDHE-RSA-CAMELLIA128-SHA256",
-    "TLS_ECDHE_RSA_WITH_CAMELLIA_256_CBC_SHA384": "ECDHE-RSA-CAMELLIA256-SHA384",
-    # Pre-shared keying (PSK) cipher suites",
-    "PSK_WITH_NULL_SHA": "PSK-NULL-SHA",
-    "DHE_PSK_WITH_NULL_SHA": "DHE-PSK-NULL-SHA",
-    "RSA_PSK_WITH_NULL_SHA": "RSA-PSK-NULL-SHA",
-    "PSK_WITH_RC4_128_SHA": "PSK-RC4-SHA",
-    "PSK_WITH_3DES_EDE_CBC_SHA": "PSK-3DES-EDE-CBC-SHA",
-    "PSK_WITH_AES_128_CBC_SHA": "PSK-AES128-CBC-SHA",
-    "PSK_WITH_AES_256_CBC_SHA": "PSK-AES256-CBC-SHA",
-    "DHE_PSK_WITH_RC4_128_SHA": "DHE-PSK-RC4-SHA",
-    "DHE_PSK_WITH_3DES_EDE_CBC_SHA": "DHE-PSK-3DES-EDE-CBC-SHA",
-    "DHE_PSK_WITH_AES_128_CBC_SHA": "DHE-PSK-AES128-CBC-SHA",
-    "DHE_PSK_WITH_AES_256_CBC_SHA": "DHE-PSK-AES256-CBC-SHA",
-    "RSA_PSK_WITH_RC4_128_SHA": "RSA-PSK-RC4-SHA",
-    "RSA_PSK_WITH_3DES_EDE_CBC_SHA": "RSA-PSK-3DES-EDE-CBC-SHA",
-    "RSA_PSK_WITH_AES_128_CBC_SHA": "RSA-PSK-AES128-CBC-SHA",
-    "RSA_PSK_WITH_AES_256_CBC_SHA": "RSA-PSK-AES256-CBC-SHA",
-    "PSK_WITH_AES_128_GCM_SHA256": "PSK-AES128-GCM-SHA256",
-    "PSK_WITH_AES_256_GCM_SHA384": "PSK-AES256-GCM-SHA384",
-    "DHE_PSK_WITH_AES_128_GCM_SHA256": "DHE-PSK-AES128-GCM-SHA256",
-    "DHE_PSK_WITH_AES_256_GCM_SHA384": "DHE-PSK-AES256-GCM-SHA384",
-    "RSA_PSK_WITH_AES_128_GCM_SHA256": "RSA-PSK-AES128-GCM-SHA256",
-    "RSA_PSK_WITH_AES_256_GCM_SHA384": "RSA-PSK-AES256-GCM-SHA384",
-    "PSK_WITH_AES_128_CBC_SHA256": "PSK-AES128-CBC-SHA256",
-    "PSK_WITH_AES_256_CBC_SHA384": "PSK-AES256-CBC-SHA384",
-    "PSK_WITH_NULL_SHA256": "PSK-NULL-SHA256",
-    "PSK_WITH_NULL_SHA384": "PSK-NULL-SHA384",
-    "DHE_PSK_WITH_AES_128_CBC_SHA256": "DHE-PSK-AES128-CBC-SHA256",
-    "DHE_PSK_WITH_AES_256_CBC_SHA384": "DHE-PSK-AES256-CBC-SHA384",
-    "DHE_PSK_WITH_NULL_SHA256": "DHE-PSK-NULL-SHA256",
-    "DHE_PSK_WITH_NULL_SHA384": "DHE-PSK-NULL-SHA384",
-    "RSA_PSK_WITH_AES_128_CBC_SHA256": "RSA-PSK-AES128-CBC-SHA256",
-    "RSA_PSK_WITH_AES_256_CBC_SHA384": "RSA-PSK-AES256-CBC-SHA384",
-    "RSA_PSK_WITH_NULL_SHA256": "RSA-PSK-NULL-SHA256",
-    "RSA_PSK_WITH_NULL_SHA384": "RSA-PSK-NULL-SHA384",
-    "ECDHE_PSK_WITH_RC4_128_SHA": "ECDHE-PSK-RC4-SHA",
-    "ECDHE_PSK_WITH_3DES_EDE_CBC_SHA": "ECDHE-PSK-3DES-EDE-CBC-SHA",
-    "ECDHE_PSK_WITH_AES_128_CBC_SHA": "ECDHE-PSK-AES128-CBC-SHA",
-    "ECDHE_PSK_WITH_AES_256_CBC_SHA": "ECDHE-PSK-AES256-CBC-SHA",
-    "ECDHE_PSK_WITH_AES_128_CBC_SHA256": "ECDHE-PSK-AES128-CBC-SHA256",
-    "ECDHE_PSK_WITH_AES_256_CBC_SHA384": "ECDHE-PSK-AES256-CBC-SHA384",
-    "ECDHE_PSK_WITH_NULL_SHA": "ECDHE-PSK-NULL-SHA",
-    "ECDHE_PSK_WITH_NULL_SHA256": "ECDHE-PSK-NULL-SHA256",
-    "ECDHE_PSK_WITH_NULL_SHA384": "ECDHE-PSK-NULL-SHA384",
-    "PSK_WITH_CAMELLIA_128_CBC_SHA256": "PSK-CAMELLIA128-SHA256",
-    "PSK_WITH_CAMELLIA_256_CBC_SHA384": "PSK-CAMELLIA256-SHA384",
-    "DHE_PSK_WITH_CAMELLIA_128_CBC_SHA256": "DHE-PSK-CAMELLIA128-SHA256",
-    "DHE_PSK_WITH_CAMELLIA_256_CBC_SHA384": "DHE-PSK-CAMELLIA256-SHA384",
-    "RSA_PSK_WITH_CAMELLIA_128_CBC_SHA256": "RSA-PSK-CAMELLIA128-SHA256",
-    "RSA_PSK_WITH_CAMELLIA_256_CBC_SHA384": "RSA-PSK-CAMELLIA256-SHA384",
-    "ECDHE_PSK_WITH_CAMELLIA_128_CBC_SHA256": "ECDHE-PSK-CAMELLIA128-SHA256",
-    "ECDHE_PSK_WITH_CAMELLIA_256_CBC_SHA384": "ECDHE-PSK-CAMELLIA256-SHA384",
-    "PSK_WITH_AES_128_CCM": "PSK-AES128-CCM",
-    "PSK_WITH_AES_256_CCM": "PSK-AES256-CCM",
-    "DHE_PSK_WITH_AES_128_CCM": "DHE-PSK-AES128-CCM",
-    "DHE_PSK_WITH_AES_256_CCM": "DHE-PSK-AES256-CCM",
-    "PSK_WITH_AES_128_CCM_8": "PSK-AES128-CCM8",
-    "PSK_WITH_AES_256_CCM_8": "PSK-AES256-CCM8",
-    "DHE_PSK_WITH_AES_128_CCM_8": "DHE-PSK-AES128-CCM8",
-    "DHE_PSK_WITH_AES_256_CCM_8": "DHE-PSK-AES256-CCM8",
-    # ChaCha20-Poly1305 cipher suites, extending TLS v1.2
-    "TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256": "ECDHE-RSA-CHACHA20-POLY1305",
-    "TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256": "ECDHE-ECDSA-CHACHA20-POLY1305",
-    "TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256": "DHE-RSA-CHACHA20-POLY1305",
-    "TLS_PSK_WITH_CHACHA20_POLY1305_SHA256": "PSK-CHACHA20-POLY1305",
-    "TLS_ECDHE_PSK_WITH_CHACHA20_POLY1305_SHA256": "ECDHE-PSK-CHACHA20-POLY1305",
-    "TLS_DHE_PSK_WITH_CHACHA20_POLY1305_SHA256": "DHE-PSK-CHACHA20-POLY1305",
-    "TLS_RSA_PSK_WITH_CHACHA20_POLY1305_SHA256": "RSA-PSK-CHACHA20-POLY1305",
-}
-
-# TLS v1.3 cipher suites IANI to OpenSSL name translation
-TLSV1_3_CIPHER_SUITES: Dict[str, str] = {
-    "TLS_AES_128_GCM_SHA256": "TLS_AES_128_GCM_SHA256",
-    "TLS_AES_256_GCM_SHA384": "TLS_AES_256_GCM_SHA384",
-    "TLS_CHACHA20_POLY1305_SHA256": "TLS_CHACHA20_POLY1305_SHA256",
-    "TLS_AES_128_CCM_SHA256": "TLS_AES_128_CCM_SHA256",
-    "TLS_AES_128_CCM_8_SHA256": "TLS_AES_128_CCM_8_SHA256",
-}
-
-TLS_CIPHER_SUITES: Dict[str, Dict[str, str]] = {
-    "TLSv1.2": TLSV1_2_CIPHER_SUITES,
-    "TLSv1.3": TLSV1_3_CIPHER_SUITES,
-}
-
-OPENSSL_CS_NAMES: Dict[str, ValuesView[str]] = {
-    "TLSv1.2": TLSV1_2_CIPHER_SUITES.values(),
-    "TLSv1.3": TLSV1_3_CIPHER_SUITES.values(),
-}
