@@ -1,16 +1,16 @@
-# Copyright (c) 2009, 2023, Oracle and/or its affiliates.
+# Copyright (c) 2009, 2024, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
 # published by the Free Software Foundation.
 #
-# This program is also distributed with certain software (including
+# This program is designed to work with certain software (including
 # but not limited to OpenSSL) that is licensed under separate terms,
 # as designated in a particular file or component or in included license
-# documentation.  The authors of MySQL hereby grant you an
+# documentation. The authors of MySQL hereby grant you an
 # additional permission to link the program and your derivative works
-# with the separately licensed software that they have included with
-# MySQL.
+# with the separately licensed software that they have either included with
+# the program or referenced in the documentation.
 #
 # Without limiting anything contained in the foregoing, this file,
 # which is part of MySQL Connector/Python, is also subject to the
@@ -54,6 +54,7 @@ from .constants import (
     FieldType,
     ServerCmd,
 )
+from .conversion import MySQLConverter
 from .errors import DatabaseError, InterfaceError, ProgrammingError, get_exception
 from .logger import logger
 from .plugins import MySQLAuthPlugin, get_auth_plugin
@@ -617,7 +618,10 @@ class MySQLProtocol:
 
     def read_text_result(
         self, sock: MySQLSocket, version: Tuple[int, ...], count: int = 1
-    ) -> Tuple[List[Tuple[Optional[bytes], ...]], Optional[EofPacketType],]:
+    ) -> Tuple[
+        List[Tuple[Optional[bytes], ...]],
+        Optional[EofPacketType],
+    ]:
         """Read MySQL text result
 
         Reads all or given number of rows from the socket.
@@ -673,6 +677,9 @@ class MySQLProtocol:
         elif field[1] == FieldType.LONGLONG:
             format_ = "<q"
             length = 8
+        else:
+            # length is undefined
+            raise ValueError("Unknown integer type")
 
         if field[7] & FieldFlag.UNSIGNED:
             format_ = format_.upper()
@@ -798,6 +805,10 @@ class MySQLProtocol:
             elif field[1] == FieldType.TIME:
                 (packet, value) = self._parse_binary_time(packet)
                 values.append(value)
+            elif field[1] == FieldType.VECTOR:
+                # pylint: disable=protected-access
+                (packet, value) = utils.read_lc_string(packet)
+                values.append(MySQLConverter._vector_to_python(value))
             elif field[7] == FieldFlag.BINARY or field[8] == 63:  # "binary" charset
                 (packet, value) = utils.read_lc_string(packet)
                 values.append(value)
@@ -816,7 +827,10 @@ class MySQLProtocol:
         columns: List[DescriptionType],
         count: int = 1,
         charset: str = "utf-8",
-    ) -> Tuple[List[Tuple[BinaryProtocolType, ...]], Optional[EofPacketType],]:
+    ) -> Tuple[
+        List[Tuple[BinaryProtocolType, ...]],
+        Optional[EofPacketType],
+    ]:
         """Read MySQL binary protocol result
 
         Reads all or given number of binary resultset rows from the socket.
