@@ -1,16 +1,16 @@
-# Copyright (c) 2009, 2023, Oracle and/or its affiliates.
+# Copyright (c) 2009, 2024, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
 # published by the Free Software Foundation.
 #
-# This program is also distributed with certain software (including
+# This program is designed to work with certain software (including
 # but not limited to OpenSSL) that is licensed under separate terms,
 # as designated in a particular file or component or in included license
-# documentation.  The authors of MySQL hereby grant you an
+# documentation. The authors of MySQL hereby grant you an
 # additional permission to link the program and your derivative works
-# with the separately licensed software that they have included with
-# MySQL.
+# with the separately licensed software that they have either included with
+# the program or referenced in the documentation.
 #
 # Without limiting anything contained in the foregoing, this file,
 # which is part of MySQL Connector/Python, is also subject to the
@@ -35,6 +35,7 @@ import struct
 import subprocess
 import sys
 import unicodedata
+import warnings
 
 from decimal import Decimal
 from functools import lru_cache
@@ -57,6 +58,7 @@ from stringprep import (
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
 from .custom_types import HexLiteral
+from .tls_ciphers import DEPRECATED_TLS_CIPHERSUITES, DEPRECATED_TLS_VERSIONS
 from .types import StrOrBytes
 
 __MYSQL_DEBUG__: bool = False
@@ -668,6 +670,45 @@ def import_object(fullpath: str) -> Any:
     return obj
 
 
+def warn_ciphersuites_deprecated(cipher_as_ossl: str, tls_version: str) -> None:
+    """Emits a warning if a deprecated cipher is being utilized.
+
+    Args:
+        cipher: Must be ingested as OpenSSL name.
+        tls_versions: TLS version to check the cipher against.
+
+    Raises:
+        DeprecationWarning: If the cipher is flagged as deprecated
+                            according to the OSSA cipher list.
+    """
+    if cipher_as_ossl in DEPRECATED_TLS_CIPHERSUITES.get(tls_version, {}).values():
+        warn_msg = (
+            f"This connection is using TLS cipher {cipher_as_ossl} which is now "
+            "deprecated and will be removed in a future release of "
+            "MySQL Connector/Python."
+        )
+        warnings.warn(warn_msg, DeprecationWarning)
+
+
+def warn_tls_version_deprecated(tls_version: str) -> None:
+    """Emits a warning if a deprecated TLS version is being utilized.
+
+    Args:
+        tls_versions: TLS version to check.
+
+    Raises:
+        DeprecationWarning: If the TLS version is flagged as deprecated
+                            according to the OSSA cipher list.
+    """
+    if tls_version in DEPRECATED_TLS_VERSIONS:
+        warn_msg = (
+            f"This connection is using TLS version {tls_version} which is now "
+            "deprecated and will be removed in a future release of "
+            "MySQL Connector/Python."
+        )
+        warnings.warn(warn_msg, DeprecationWarning)
+
+
 class GenericWrapper:
     """Base class that provides basic object wrapper functionality."""
 
